pub enum Arg<'a> {
Void,
Scalar(Scalar),
Aggregate(Shape<'a>),
}Expand description
One argument, or one return value, as much of it as an ABI cares about.
Variants
Void
void, which is a return type and never an argument.
Scalar(Scalar)
A scalar.
Aggregate(Shape<'a>)
A struct, a union, an array or a _Complex.