pub enum Lane {
I8,
U8,
I16,
U16,
I32,
U32,
I64,
U64,
F16,
F32,
F64,
}Expand description
What one lane of a vector is.
Variants
I8
signed char.
U8
unsigned char, which is also the lane of a polynomial of eight bits.
I16
short.
U16
unsigned short.
I32
int.
U32
unsigned int.
I64
long, which is sixty four bits on every target these are for.
U64
unsigned long.
F16
_Float16.
F32
float.
F64
double.