Where

Enum Where 

pub enum Where {
    Reg(PhysReg),
    Stack(u32),
}
Where one of the values a call passes is.

Variants



Reg(PhysReg)

In that register.



Stack(u32)

That many bytes up the argument area, which is where the stack pointer points at the instruction that makes the call and is one word above the return address in the callee.